@@ -12,3 +12,5 @@
 #define BADRECORD 8
 #define OTHERERROR 9
 #define RANGEERROR 10
+#define NOTSORTED 11
+#define BADENCODING 12
