@@ -1,7 +1,7 @@
-/* Time-stamp: <2007-10-05 02:01:30 poser> */
+/* Time-stamp: <2008-03-14 18:09:50 poser> */
 
 /*
- * Copyright (C) 1993-2007 William J. Poser.
+ * Copyright (C) 1993-2008 William J. Poser.
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 3 of the GNU General Public License
  * as published by the Free Software Foundation.
@@ -12,8 +12,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, write to the Free Software Foundation,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #include "config.h"
@@ -46,12 +46,14 @@
 #include <tre/regex.h>
 #include "key.h"
 #ifdef HAVE_UNINUM_UNICODE_H
+#include <uninum/nsdefs.h>
 #include <uninum/unicode.h>
 #else
 #include "unicode.h"
 #endif
-#include <uninum/nsdefs.h>
+#ifdef HAVE_UNINUM_UNINUM_H
 #include <uninum/uninum.h>
+#endif
 #include "dstr.h"
 #include "exitcode.h"
 #include "retcodes.h"
